# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: IpcConnectionContext.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='IpcConnectionContext.proto',
  package='hadoop.common',
  syntax='proto2',
  serialized_pb=_b('\n\x1aIpcConnectionContext.proto\x12\rhadoop.common\"?\n\x14UserInformationProto\x12\x15\n\reffectiveUser\x18\x01 \x01(\t\x12\x10\n\x08realUser\x18\x02 \x01(\t\"d\n\x19IpcConnectionContextProto\x12\x35\n\x08userInfo\x18\x02 \x01(\x0b\x32#.hadoop.common.UserInformationProto\x12\x10\n\x08protocol\x18\x03 \x01(\tB?\n\x1eorg.apache.hadoop.ipc.protobufB\x1aIpcConnectionContextProtos\xa0\x01\x01')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERINFORMATIONPROTO = _descriptor.Descriptor(
  name='UserInformationProto',
  full_name='hadoop.common.UserInformationProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='effectiveUser', full_name='hadoop.common.UserInformationProto.effectiveUser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='realUser', full_name='hadoop.common.UserInformationProto.realUser', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=108,
)


_IPCCONNECTIONCONTEXTPROTO = _descriptor.Descriptor(
  name='IpcConnectionContextProto',
  full_name='hadoop.common.IpcConnectionContextProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userInfo', full_name='hadoop.common.IpcConnectionContextProto.userInfo', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='hadoop.common.IpcConnectionContextProto.protocol', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=210,
)

_IPCCONNECTIONCONTEXTPROTO.fields_by_name['userInfo'].message_type = _USERINFORMATIONPROTO
DESCRIPTOR.message_types_by_name['UserInformationProto'] = _USERINFORMATIONPROTO
DESCRIPTOR.message_types_by_name['IpcConnectionContextProto'] = _IPCCONNECTIONCONTEXTPROTO

UserInformationProto = _reflection.GeneratedProtocolMessageType('UserInformationProto', (_message.Message,), dict(
  DESCRIPTOR = _USERINFORMATIONPROTO,
  __module__ = 'IpcConnectionContext_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.UserInformationProto)
  ))
_sym_db.RegisterMessage(UserInformationProto)

IpcConnectionContextProto = _reflection.GeneratedProtocolMessageType('IpcConnectionContextProto', (_message.Message,), dict(
  DESCRIPTOR = _IPCCONNECTIONCONTEXTPROTO,
  __module__ = 'IpcConnectionContext_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.IpcConnectionContextProto)
  ))
_sym_db.RegisterMessage(IpcConnectionContextProto)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\036org.apache.hadoop.ipc.protobufB\032IpcConnectionContextProtos\240\001\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RpcHeader.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='RpcHeader.proto',
  package='hadoop.common',
  syntax='proto2',
  serialized_pb=_b('\n\x0fRpcHeader.proto\x12\rhadoop.common\"\xa2\x02\n\x15RpcRequestHeaderProto\x12,\n\x07rpcKind\x18\x01 \x01(\x0e\x32\x1b.hadoop.common.RpcKindProto\x12\x42\n\x05rpcOp\x18\x02 \x01(\x0e\x32\x33.hadoop.common.RpcRequestHeaderProto.OperationProto\x12\x0e\n\x06\x63\x61llId\x18\x03 \x02(\x11\x12\x10\n\x08\x63lientId\x18\x04 \x02(\x0c\x12\x16\n\nretryCount\x18\x05 \x01(\x11:\x02-1\"]\n\x0eOperationProto\x12\x14\n\x10RPC_FINAL_PACKET\x10\x00\x12\x1b\n\x17RPC_CONTINUATION_PACKET\x10\x01\x12\x18\n\x14RPC_CLOSE_CONNECTION\x10\x02\"\xca\x05\n\x16RpcResponseHeaderProto\x12\x0e\n\x06\x63\x61llId\x18\x01 \x02(\r\x12\x44\n\x06status\x18\x02 \x02(\x0e\x32\x34.hadoop.common.RpcResponseHeaderProto.RpcStatusProto\x12\x1b\n\x13serverIpcVersionNum\x18\x03 \x01(\r\x12\x1a\n\x12\x65xceptionClassName\x18\x04 \x01(\t\x12\x10\n\x08\x65rrorMsg\x18\x05 \x01(\t\x12L\n\x0b\x65rrorDetail\x18\x06 \x01(\x0e\x32\x37.hadoop.common.RpcResponseHeaderProto.RpcErrorCodeProto\x12\x10\n\x08\x63lientId\x18\x07 \x01(\x0c\x12\x16\n\nretryCount\x18\x08 \x01(\x11:\x02-1\"3\n\x0eRpcStatusProto\x12\x0b\n\x07SUCCESS\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\t\n\x05\x46\x41TAL\x10\x02\"\xe1\x02\n\x11RpcErrorCodeProto\x12\x15\n\x11\x45RROR_APPLICATION\x10\x01\x12\x18\n\x14\x45RROR_NO_SUCH_METHOD\x10\x02\x12\x1a\n\x16\x45RROR_NO_SUCH_PROTOCOL\x10\x03\x12\x14\n\x10\x45RROR_RPC_SERVER\x10\x04\x12\x1e\n\x1a\x45RROR_SERIALIZING_RESPONSE\x10\x05\x12\x1e\n\x1a\x45RROR_RPC_VERSION_MISMATCH\x10\x06\x12\x11\n\rFATAL_UNKNOWN\x10\n\x12#\n\x1f\x46\x41TAL_UNSUPPORTED_SERIALIZATION\x10\x0b\x12\x1c\n\x18\x46\x41TAL_INVALID_RPC_HEADER\x10\x0c\x12\x1f\n\x1b\x46\x41TAL_DESERIALIZING_REQUEST\x10\r\x12\x1a\n\x16\x46\x41TAL_VERSION_MISMATCH\x10\x0e\x12\x16\n\x12\x46\x41TAL_UNAUTHORIZED\x10\x0f\"\xdd\x02\n\x0cRpcSaslProto\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x34\n\x05state\x18\x02 \x02(\x0e\x32%.hadoop.common.RpcSaslProto.SaslState\x12\r\n\x05token\x18\x03 \x01(\x0c\x12\x33\n\x05\x61uths\x18\x04 \x03(\x0b\x32$.hadoop.common.RpcSaslProto.SaslAuth\x1a\x64\n\x08SaslAuth\x12\x0e\n\x06method\x18\x01 \x02(\t\x12\x11\n\tmechanism\x18\x02 \x02(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x10\n\x08serverId\x18\x04 \x01(\t\x12\x11\n\tchallenge\x18\x05 \x01(\x0c\"\\\n\tSaslState\x12\x0b\n\x07SUCCESS\x10\x00\x12\r\n\tNEGOTIATE\x10\x01\x12\x0c\n\x08INITIATE\x10\x02\x12\r\n\tCHALLENGE\x10\x03\x12\x0c\n\x08RESPONSE\x10\x04\x12\x08\n\x04WRAP\x10\x05*J\n\x0cRpcKindProto\x12\x0f\n\x0bRPC_BUILTIN\x10\x00\x12\x10\n\x0cRPC_WRITABLE\x10\x01\x12\x17\n\x13RPC_PROTOCOL_BUFFER\x10\x02\x42\x34\n\x1eorg.apache.hadoop.ipc.protobufB\x0fRpcHeaderProtos\xa0\x01\x01')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_RPCKINDPROTO = _descriptor.EnumDescriptor(
  name='RpcKindProto',
  full_name='hadoop.common.RpcKindProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RPC_BUILTIN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_WRITABLE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_PROTOCOL_BUFFER', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1396,
  serialized_end=1470,
)
_sym_db.RegisterEnumDescriptor(_RPCKINDPROTO)

RpcKindProto = enum_type_wrapper.EnumTypeWrapper(_RPCKINDPROTO)
RPC_BUILTIN = 0
RPC_WRITABLE = 1
RPC_PROTOCOL_BUFFER = 2


_RPCREQUESTHEADERPROTO_OPERATIONPROTO = _descriptor.EnumDescriptor(
  name='OperationProto',
  full_name='hadoop.common.RpcRequestHeaderProto.OperationProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RPC_FINAL_PACKET', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_CONTINUATION_PACKET', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_CLOSE_CONNECTION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=232,
  serialized_end=325,
)
_sym_db.RegisterEnumDescriptor(_RPCREQUESTHEADERPROTO_OPERATIONPROTO)

_RPCRESPONSEHEADERPROTO_RPCSTATUSPROTO = _descriptor.EnumDescriptor(
  name='RpcStatusProto',
  full_name='hadoop.common.RpcResponseHeaderProto.RpcStatusProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=635,
  serialized_end=686,
)
_sym_db.RegisterEnumDescriptor(_RPCRESPONSEHEADERPROTO_RPCSTATUSPROTO)

_RPCRESPONSEHEADERPROTO_RPCERRORCODEPROTO = _descriptor.EnumDescriptor(
  name='RpcErrorCodeProto',
  full_name='hadoop.common.RpcResponseHeaderProto.RpcErrorCodeProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR_APPLICATION', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_SUCH_METHOD', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_SUCH_PROTOCOL', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_RPC_SERVER', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_SERIALIZING_RESPONSE', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_RPC_VERSION_MISMATCH', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL_UNKNOWN', index=6, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL_UNSUPPORTED_SERIALIZATION', index=7, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL_INVALID_RPC_HEADER', index=8, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL_DESERIALIZING_REQUEST', index=9, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL_VERSION_MISMATCH', index=10, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATAL_UNAUTHORIZED', index=11, number=15,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=689,
  serialized_end=1042,
)
_sym_db.RegisterEnumDescriptor(_RPCRESPONSEHEADERPROTO_RPCERRORCODEPROTO)

_RPCSASLPROTO_SASLSTATE = _descriptor.EnumDescriptor(
  name='SaslState',
  full_name='hadoop.common.RpcSaslProto.SaslState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEGOTIATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIATE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHALLENGE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESPONSE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRAP', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1302,
  serialized_end=1394,
)
_sym_db.RegisterEnumDescriptor(_RPCSASLPROTO_SASLSTATE)


_RPCREQUESTHEADERPROTO = _descriptor.Descriptor(
  name='RpcRequestHeaderProto',
  full_name='hadoop.common.RpcRequestHeaderProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rpcKind', full_name='hadoop.common.RpcRequestHeaderProto.rpcKind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rpcOp', full_name='hadoop.common.RpcRequestHeaderProto.rpcOp', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='callId', full_name='hadoop.common.RpcRequestHeaderProto.callId', index=2,
      number=3, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='hadoop.common.RpcRequestHeaderProto.clientId', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='retryCount', full_name='hadoop.common.RpcRequestHeaderProto.retryCount', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RPCREQUESTHEADERPROTO_OPERATIONPROTO,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=325,
)


_RPCRESPONSEHEADERPROTO = _descriptor.Descriptor(
  name='RpcResponseHeaderProto',
  full_name='hadoop.common.RpcResponseHeaderProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='callId', full_name='hadoop.common.RpcResponseHeaderProto.callId', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='hadoop.common.RpcResponseHeaderProto.status', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serverIpcVersionNum', full_name='hadoop.common.RpcResponseHeaderProto.serverIpcVersionNum', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exceptionClassName', full_name='hadoop.common.RpcResponseHeaderProto.exceptionClassName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errorMsg', full_name='hadoop.common.RpcResponseHeaderProto.errorMsg', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errorDetail', full_name='hadoop.common.RpcResponseHeaderProto.errorDetail', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='hadoop.common.RpcResponseHeaderProto.clientId', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='retryCount', full_name='hadoop.common.RpcResponseHeaderProto.retryCount', index=7,
      number=8, type=17, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RPCRESPONSEHEADERPROTO_RPCSTATUSPROTO,
    _RPCRESPONSEHEADERPROTO_RPCERRORCODEPROTO,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=1042,
)


_RPCSASLPROTO_SASLAUTH = _descriptor.Descriptor(
  name='SaslAuth',
  full_name='hadoop.common.RpcSaslProto.SaslAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='hadoop.common.RpcSaslProto.SaslAuth.method', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mechanism', full_name='hadoop.common.RpcSaslProto.SaslAuth.mechanism', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='hadoop.common.RpcSaslProto.SaslAuth.protocol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='hadoop.common.RpcSaslProto.SaslAuth.serverId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge', full_name='hadoop.common.RpcSaslProto.SaslAuth.challenge', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1200,
  serialized_end=1300,
)

_RPCSASLPROTO = _descriptor.Descriptor(
  name='RpcSaslProto',
  full_name='hadoop.common.RpcSaslProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='hadoop.common.RpcSaslProto.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='hadoop.common.RpcSaslProto.state', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='hadoop.common.RpcSaslProto.token', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auths', full_name='hadoop.common.RpcSaslProto.auths', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_RPCSASLPROTO_SASLAUTH, ],
  enum_types=[
    _RPCSASLPROTO_SASLSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1394,
)

_RPCREQUESTHEADERPROTO.fields_by_name['rpcKind'].enum_type = _RPCKINDPROTO
_RPCREQUESTHEADERPROTO.fields_by_name['rpcOp'].enum_type = _RPCREQUESTHEADERPROTO_OPERATIONPROTO
_RPCREQUESTHEADERPROTO_OPERATIONPROTO.containing_type = _RPCREQUESTHEADERPROTO
_RPCRESPONSEHEADERPROTO.fields_by_name['status'].enum_type = _RPCRESPONSEHEADERPROTO_RPCSTATUSPROTO
_RPCRESPONSEHEADERPROTO.fields_by_name['errorDetail'].enum_type = _RPCRESPONSEHEADERPROTO_RPCERRORCODEPROTO
_RPCRESPONSEHEADERPROTO_RPCSTATUSPROTO.containing_type = _RPCRESPONSEHEADERPROTO
_RPCRESPONSEHEADERPROTO_RPCERRORCODEPROTO.containing_type = _RPCRESPONSEHEADERPROTO
_RPCSASLPROTO_SASLAUTH.containing_type = _RPCSASLPROTO
_RPCSASLPROTO.fields_by_name['state'].enum_type = _RPCSASLPROTO_SASLSTATE
_RPCSASLPROTO.fields_by_name['auths'].message_type = _RPCSASLPROTO_SASLAUTH
_RPCSASLPROTO_SASLSTATE.containing_type = _RPCSASLPROTO
DESCRIPTOR.message_types_by_name['RpcRequestHeaderProto'] = _RPCREQUESTHEADERPROTO
DESCRIPTOR.message_types_by_name['RpcResponseHeaderProto'] = _RPCRESPONSEHEADERPROTO
DESCRIPTOR.message_types_by_name['RpcSaslProto'] = _RPCSASLPROTO
DESCRIPTOR.enum_types_by_name['RpcKindProto'] = _RPCKINDPROTO

RpcRequestHeaderProto = _reflection.GeneratedProtocolMessageType('RpcRequestHeaderProto', (_message.Message,), dict(
  DESCRIPTOR = _RPCREQUESTHEADERPROTO,
  __module__ = 'RpcHeader_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.RpcRequestHeaderProto)
  ))
_sym_db.RegisterMessage(RpcRequestHeaderProto)

RpcResponseHeaderProto = _reflection.GeneratedProtocolMessageType('RpcResponseHeaderProto', (_message.Message,), dict(
  DESCRIPTOR = _RPCRESPONSEHEADERPROTO,
  __module__ = 'RpcHeader_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.RpcResponseHeaderProto)
  ))
_sym_db.RegisterMessage(RpcResponseHeaderProto)

RpcSaslProto = _reflection.GeneratedProtocolMessageType('RpcSaslProto', (_message.Message,), dict(

  SaslAuth = _reflection.GeneratedProtocolMessageType('SaslAuth', (_message.Message,), dict(
    DESCRIPTOR = _RPCSASLPROTO_SASLAUTH,
    __module__ = 'RpcHeader_pb2'
    # @@protoc_insertion_point(class_scope:hadoop.common.RpcSaslProto.SaslAuth)
    ))
  ,
  DESCRIPTOR = _RPCSASLPROTO,
  __module__ = 'RpcHeader_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.common.RpcSaslProto)
  ))
_sym_db.RegisterMessage(RpcSaslProto)
_sym_db.RegisterMessage(RpcSaslProto.SaslAuth)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\036org.apache.hadoop.ipc.protobufB\017RpcHeaderProtos\240\001\001'))
# @@protoc_insertion_point(module_scope)
